@@ -2,6 +2,7 @@
 
 import os
 import warnings
+import logging
 import requests
 import urllib3
 
@@ -13,6 +14,8 @@ from zeep.wsse.username import UsernameToken
 
 from .utils import ONVIFOperationException, ZeepPatcher
 
+logger = logging.getLogger(__name__)
+
 
 class CacheMode(Enum):
     """WSDL caching strategies for ONVIF client performance optimization.
@@ -68,6 +71,7 @@ class ONVIFOperator:
         address (str): Service endpoint URL (XAddr)
         client: Zeep SOAP client instance
         service: Zeep service proxy for making SOAP calls
+        service_name (str): Name of the ONVIF service (e.g., "Device", "Media")
     """
 
     def __init__(
@@ -88,6 +92,8 @@ class ONVIFOperator:
         apply_patch: bool = True,
         plugins: list = None,
     ):
+        logger.debug(f"Creating ONVIFOperator for {host}:{port} with WSDL: {wsdl_path}")
+
         self.wsdl_path = wsdl_path
         self.host = host
         self.port = port
@@ -103,12 +109,15 @@ class ONVIFOperator:
             path = service_path or "device_service"  # default fallback
             self.address = f"{protocol}://{host}:{port}/onvif/{path}"
 
+        logger.debug(f"Service endpoint: {self.address}")
+
         # Session reuse with retry strategy
         session = requests.Session()
         session.verify = verify_ssl
 
         # Format SSL warnings to be more concise when verify_ssl is False
         if not verify_ssl:
+            logger.debug("SSL verification disabled")
             warnings.simplefilter("once", urllib3.exceptions.InsecureRequestWarning)
 
         transport_kwargs = {"session": session, "timeout": timeout}
@@ -119,6 +128,7 @@ class ONVIFOperator:
                 os.makedirs(user_cache_dir, exist_ok=True)
                 cache_path = os.path.join(user_cache_dir, "onvif_zeep_cache.sqlite")
 
+            logger.debug(f"Using SQLite cache: {cache_path}")
             transport_kwargs["cache"] = SqliteCache(path=cache_path)
 
         transport = Transport(**transport_kwargs)
@@ -142,6 +152,8 @@ class ONVIFOperator:
         else:
             raise ValueError(f"Unknown cache option: {cache}")
 
+        logger.debug(f"Using cache mode: {cache.value}")
+
         self.client = ClientType(
             wsdl=self.wsdl_path,
             transport=transport,
@@ -154,7 +166,10 @@ class ONVIFOperator:
             raise ValueError("Bindings must be set according to the WSDL service")
 
         self.service = self.client.create_service(binding, self.address)
-        # logging.debug(f"ONVIFOperator initialized {binding} at {self.address}")
+        self.service_name = binding.split("}")[-1].replace(
+            "Binding", ""
+        )  # Store cleaned service name for logging context
+        logger.info(f"ONVIFOperator initialized {binding} at {self.address}")
 
     def call(self, method: str, *args, **kwargs):
         """Call an ONVIF service operation.
@@ -174,22 +189,28 @@ class ONVIFOperator:
         Raises:
             ONVIFOperationException: If the operation fails (wraps original exception)
         """
+        logger.debug(f"Calling ONVIF method: {self.service_name}.{method}")
+
         try:
             func = getattr(self.service, method)
         except AttributeError as e:
+            logger.error(f"Method {method} not found in {self.service_name} service")
             raise ONVIFOperationException(operation=method, original_exception=e)
 
         try:
             result = func(*args, **kwargs)
+            logger.debug(f"ONVIF call {self.service_name}.{method} succeeded")
+
             # Post-process to flatten xsd:any fields if enabled (> v0.0.4 patch)
             if self.apply_patch:
-                return ZeepPatcher.flatten_xsd_any_fields(result)
+                result = ZeepPatcher.flatten_xsd_any_fields(result)
             return result
+
         except Fault as e:
-            # logging.error(f"SOAP Fault in {method}: {e}")
+            logger.error(f"SOAP Fault in {self.service_name}.{method}: {e}")
             raise ONVIFOperationException(operation=method, original_exception=e)
         except Exception as e:
-            # logging.error(f"ONVIF call error in {method}: {e}")
+            logger.error(f"ONVIF call error in {self.service_name}.{method}: {e}")
             raise ONVIFOperationException(operation=method, original_exception=e)
 
     def create_type(self, type_name: str):
@@ -208,6 +229,8 @@ class ONVIFOperator:
         Raises:
             AttributeError: If type not found in WSDL schema
         """
+        logger.debug(f"Creating type instance for: {type_name}")
+
         # Method 1: Try to get element from WSDL (works for operation parameters)
         # Common namespace prefixes for ONVIF services
         namespaces_to_try = [
@@ -220,17 +243,24 @@ class ONVIFOperator:
             try:
                 element = self.client.get_element(f"{ns}:{type_name}")
                 instance = element()
+                logger.debug(
+                    f"Successfully created type {type_name} using namespace {ns}"
+                )
                 return self._initialize_nested_types(instance)
-            except Exception:
+            except Exception as e:
+                logger.debug(
+                    f"Failed to create type {type_name} with namespace {ns}: {e}"
+                )
                 continue
 
         # Method 2: Try without namespace prefix
         try:
             element = self.client.get_element(type_name)
             instance = element()
+            logger.debug(f"Successfully created type {type_name} without namespace")
             return self._initialize_nested_types(instance)
-        except Exception:
-            pass
+        except Exception as e:
+            logger.debug(f"Failed to create element {type_name} without namespace: {e}")
 
         # Method 3: Try to get type from schema (for complex types)
         try:
@@ -238,17 +268,30 @@ class ONVIFOperator:
                 try:
                     type_obj = self.client.get_type(f"{ns}:{type_name}")
                     instance = type_obj()
+                    logger.debug(
+                        f"Successfully created complex type {type_name} using namespace {ns}"
+                    )
                     return self._initialize_nested_types(instance)
-                except Exception:
+                except Exception as e:
+                    logger.debug(
+                        f"Failed to create complex type {type_name} with namespace {ns}: {e}"
+                    )
                     continue
 
             # Try without namespace
             type_obj = self.client.get_type(type_name)
             instance = type_obj()
+            logger.debug(
+                f"Successfully created complex type {type_name} without namespace"
+            )
             return self._initialize_nested_types(instance)
-        except Exception:
-            pass
+        except Exception as e:
+            logger.debug(
+                f"Failed to create complex type {type_name} without namespace: {e}"
+            )
 
+        # If all methods fail, log the error and raise
+        logger.error(f"Type '{type_name}' not found in WSDL schema using any method")
         raise AttributeError(f"Type '{type_name}' not found in WSDL schema.")
 
     def _initialize_nested_types(self, instance):
@@ -280,15 +323,26 @@ class ONVIFOperator:
 
                             # Check if this is a complex type (has elements)
                             if hasattr(element_type, "elements"):
-                                # Complex type - instantiate it and recursively initialize
-                                nested_instance = element_type()
-                                nested_instance = self._initialize_nested_types(
-                                    nested_instance
-                                )
-                                setattr(instance, element_name, nested_instance)
-        except Exception:
-            # If anything goes wrong during nested initialization, just return the instance
+                                try:
+                                    # Complex type - instantiate it and recursively initialize
+                                    nested_instance = element_type()
+                                    nested_instance = self._initialize_nested_types(
+                                        nested_instance
+                                    )
+                                    setattr(instance, element_name, nested_instance)
+                                    logger.debug(
+                                        f"Initialized nested type for element: {element_name}"
+                                    )
+                                except Exception as e:
+                                    # Log specific nested type initialization failures
+                                    logger.debug(
+                                        f"Failed to initialize nested type for {element_name}: {e}"
+                                    )
+                                    # Continue with other elements instead of failing completely
+                                    continue
+        except Exception as e:
+            # Log the error but don't fail - the top-level object is still usable
+            logger.debug(f"Error during nested type initialization: {e}")
             # The important thing is that the top-level object is created
-            pass
 
         return instance
